<?php

namespace Drupal\grid_widget\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\OptionsButtonsWidget;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'options_grid' widget.
 *
 * @FieldWidget(
 *   id = "options_grid",
 *   module = "grid_widget",
 *   label = @Translation("Options Grid"),
 *   field_types = {
 *     "entity_reference",
 *     "list_integer",
 *     "list_float",
 *     "list_string",
 *   },
 *   multiple_values = TRUE
 * )
 */
class OptionsGridWidget extends OptionsButtonsWidget {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'size' => 3
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $element['size'] = [
      '#type' => 'number',
      '#title' => t('Number of columns'),
      '#default_value' => $this->getSetting('size'),
      '#required' => TRUE,
      '#min' => 2,
      '#max' => 8,
      '#step' => 1,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];

    $summary[] = t('Number of columns: @size', ['@size' => $this->getSetting('size')]);

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function form(FieldItemListInterface $items, array &$form, FormStateInterface $form_state, $get_delta = NULL) {
    $field_widget_complete_form = parent::form($items, $form, $form_state, $get_delta);

    if ($this->multiple) {
      $field_widget_complete_form['#attached']['library'][] = 'grid_widget/options_grid_checkboxes';
    }
    else {
      $field_widget_complete_form['#attached']['library'][] = 'grid_widget/options_grid_radios';
    }

    $field_widget_complete_form['#attributes']['data-grid-size'] = (int) $this->getSetting('size');

    return $field_widget_complete_form;
  }

}
